@@ -135,6 +135,7 @@ main(int argc, char* argv[])
   gchar* synctex_editor = NULL;
   gchar* synctex_fwd    = NULL;
   gchar* mode           = NULL;
+  gchar* search_string  = NULL;
   bool   forkback       = false;
   bool   print_version  = false;
   int    page_number    = ZATHURA_PAGE_NUMBER_UNSPECIFIED;
@@ -156,6 +157,7 @@ main(int argc, char* argv[])
     { "synctex-forward",        '\0', 0, G_OPTION_ARG_STRING,   &synctex_fwd,    _("Move to given synctex position"),                    "position" },
     { "synctex-pid",            '\0', 0, G_OPTION_ARG_INT,      &synctex_pid,    _("Highlight given position in the given process"),     "pid" },
     { "mode",                   '\0', 0, G_OPTION_ARG_STRING,   &mode,           _("Start in a non-default mode"),                       "mode" },
+    { "find",                   'f',  0, G_OPTION_ARG_STRING,   &search_string,  _("Search for the given phrase and display results"),   "string" },
     { NULL, '\0', 0, 0, NULL, NULL, NULL }
   };
 
@@ -297,7 +299,12 @@ main(int argc, char* argv[])
       --page_number;
     }
     document_open_idle(zathura, argv[file_idx], password, page_number, mode,
-                       synctex_fwd);
+                       synctex_fwd, search_string);
+  } else if (search_string != NULL) {
+    girara_error("Can not use find argument when no file is given");
+    ret = -1;
+    zathura_free(zathura);
+    goto free_and_ret;
   }
 
   /* run zathura */
@@ -316,6 +323,7 @@ free_and_ret:
   g_free(synctex_editor);
   g_free(synctex_fwd);
   g_free(mode);
+  g_free(search_string);
 
   return ret;
 }
