@@ -303,5 +303,15 @@ bool sc_exec(girara_session_t* session, girara_argument_t* argument, girara_even
  */
 bool sc_nohlsearch(girara_session_t* session, girara_argument_t* argument, girara_event_t* event, unsigned int t);
 
+/**
+ * Snaps the current view to the current page
+ *
+ * @param session The used girara session
+ * @param argument The used argument
+ * @param event Girara event
+ * @param t Number of executions
+ * @return true if no error occurred otherwise false
+ */
+bool sc_snap_to_page(girara_session_t *session, girara_argument_t *argument, girara_event_t *event, unsigned int t);
 
 #endif // SHORTCUTS_H
